abacusai.chatllm_computer — AbacusAI documentation

# abacusai.chatllm_computer

## Classes

`ChatllmComputer` | ChatLLMComputer

## Module Contents

class abacusai.chatllm_computer.ChatllmComputer(client, computerId=None, token=None, vncEndpoint=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  ChatLLMComputer

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - computerId (int) – The computer id.

    - token (str) – The token.

    - vncEndpoint (str) – The VNC endpoint.

  computer_id = None
  token = None
  vnc_endpoint = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict